==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/SecretBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class SecretBuildSourceBuilder extends SecretBuildSourceFluentImpl<SecretBuildSourceBuilder> implements VisitableBuilder<SecretBuildSource,SecretBuildSourceBuilder>{

    SecretBuildSourceFluent<?> fluent;
    Boolean validationEnabled;

    public SecretBuildSourceBuilder(){
            this(true);
    }
    public SecretBuildSourceBuilder(Boolean validationEnabled){
            this(new SecretBuildSource(), validationEnabled);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent){
            this(fluent, true);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SecretBuildSource(), validationEnabled);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,SecretBuildSource instance){
            this(fluent, instance, true);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,SecretBuildSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDestinationDir(instance.getDestinationDir()); 
            fluent.withSecret(instance.getSecret()); 
            this.validationEnabled = validationEnabled; 
    }
    public SecretBuildSourceBuilder(SecretBuildSource instance){
            this(instance,true);
    }
    public SecretBuildSourceBuilder(SecretBuildSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSecret(instance.getSecret()); 
            this.validationEnabled = validationEnabled; 
    }

    public SecretBuildSource build(){
            SecretBuildSource buildable = new SecretBuildSource(fluent.getDestinationDir(),fluent.getSecret());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SecretBuildSourceBuilder that = (SecretBuildSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.74-sources.jar: io/fabric8/openshift/api/model/SecretBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SecretBuildSourceBuilder extends SecretBuildSourceFluentImpl<SecretBuildSourceBuilder> implements VisitableBuilder<SecretBuildSource,SecretBuildSourceBuilder>{

    SecretBuildSourceFluent<?> fluent;
    Boolean validationEnabled;

    public SecretBuildSourceBuilder(){
            this(true);
    }
    public SecretBuildSourceBuilder(Boolean validationEnabled){
            this(new SecretBuildSource(), validationEnabled);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent){
            this(fluent, true);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SecretBuildSource(), validationEnabled);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,SecretBuildSource instance){
            this(fluent, instance, true);
    }
    public SecretBuildSourceBuilder(SecretBuildSourceFluent<?> fluent,SecretBuildSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDestinationDir(instance.getDestinationDir()); 
            fluent.withSecret(instance.getSecret()); 
            this.validationEnabled = validationEnabled; 
    }
    public SecretBuildSourceBuilder(SecretBuildSource instance){
            this(instance,true);
    }
    public SecretBuildSourceBuilder(SecretBuildSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSecret(instance.getSecret()); 
            this.validationEnabled = validationEnabled; 
    }

    public SecretBuildSource build(){
            SecretBuildSource buildable = new SecretBuildSource(fluent.getDestinationDir(),fluent.getSecret());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SecretBuildSourceBuilder that = (SecretBuildSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
